@@ -103,6 +103,7 @@ class API:
 
         try:
             with open(cfg) as file:
+                self._config = None
                 self._config = yaml.safe_load(file)
         except EnvironmentError:
             notify(f"Cannot open configuration file: {cfg}\n")
@@ -452,6 +453,27 @@ class API:
         notify("\n")
         return None
 
+    def fix_search(self):
+        """fix_search_index."""
+
+        home = str(Path.home())
+        cfg = os.path.join(home, CONFIG_DIR, "fixed_search.txt")
+        if os.path.isfile(cfg) is True:
+            notify("Not required - already fixed")
+            return False
+
+        res = self.members.fix_search()
+        if res is False:
+            return res
+
+        with open(cfg, mode="w") as file:
+            file.write(f"Fixed index: {self.today}")
+
+        msg = "Index recreated - give SCM time to process changes before testing."
+        notify(f"\n{msg}\n")
+
+        return True
+
     def apply_fixes(self):
         """Apply any fixes."""
         if len(self.fixable) == 0:
